@@ -9,7 +9,7 @@ spec_meta_get_rows_affected <- list(
     expect_equal(names(formals(dbGetRowsAffected)), c("res", "..."))
   },
 
-  rows_affected_statement = function(con, table_name) {
+  rows_affected_statement = function(ctx, con, table_name) {
     #' @return
     #' `dbGetRowsAffected()` returns a scalar number (integer or numeric),
     #' the number of rows affected by a data manipulation statement
@@ -23,15 +23,25 @@ spec_meta_get_rows_affected <- list(
     res <- local_result(dbSendStatement(con, query))
     rc <- dbGetRowsAffected(res)
     #' The value is available directly after the call
-    expect_equal(rc, 5L)
+    if (isTRUE(ctx$tweaks$allow_na_rows_affected)) {
+      expect_true((is.na(rc) && is.numeric(rc)) || rc == 5L)
+    } else {
+      expect_equal(rc, 5L)
+    }
     expect_warning(check_df(dbFetch(res)))
     rc <- dbGetRowsAffected(res)
     #' and does not change after calling [dbFetch()].
-    expect_equal(rc, 5L)
+    if (isTRUE(ctx$tweaks$allow_na_rows_affected)) {
+      expect_true((is.na(rc) && is.numeric(rc)) || rc == 5L)
+    } else {
+      expect_equal(rc, 5L)
+    }
+    #' `NA_integer_` or `NA_numeric_` are allowed if the number of rows affected is not known.
   },
   #
-  rows_affected_query = function(con) {
+  rows_affected_query = function(ctx, con) {
     query <- trivial_query()
+    #'
     #' For queries issued with [dbSendQuery()],
     res <- local_result(dbSendQuery(con, query))
     rc <- dbGetRowsAffected(res)
@@ -41,6 +51,7 @@ spec_meta_get_rows_affected <- list(
     rc <- dbGetRowsAffected(res)
     #' and after the call to `dbFetch()`.
     expect_equal(rc, 0L)
+    #' `NA` values are not allowed.
   },
   #'
   get_rows_affected_error = function(con, table_name) {
