@@ -26,7 +26,7 @@ spec_result_roundtrip <- list(
     sql_names <- paste0("CAST(", int_values, " AS ", dbDataType(con, logical()), ")")
 
     #' with NA for SQL `NULL` values
-    test_select_with_null(.ctx = ctx, con, .dots = setNames(values, sql_names))
+    test_select_with_null(.ctx = ctx, con, !!!setNames(values, sql_names))
   },
 
   data_character = function(ctx, con) {
@@ -36,8 +36,8 @@ spec_result_roundtrip <- list(
     sql_names <- as.character(dbQuoteString(con, values))
 
     #' with NA for SQL `NULL` values
-    test_select_with_null(.ctx = ctx, con, .dots = setNames(values, sql_names))
-    test_select_with_null(.ctx = ctx, con, .dots = setNames(test_funs, sql_names))
+    test_select_with_null(.ctx = ctx, con, !!!setNames(values, sql_names))
+    test_select_with_null(.ctx = ctx, con, !!!setNames(test_funs, sql_names))
   },
 
   data_raw = function(ctx, con) {
@@ -54,13 +54,13 @@ spec_result_roundtrip <- list(
     sql_names <- ctx$tweaks$blob_cast(DBI::dbQuoteLiteral(con, list(raw(1))))
 
     #' with [NULL] entries for SQL NULL values
-    test_select_with_null(.ctx = ctx, con, .dots = setNames(values, sql_names))
+    test_select_with_null(.ctx = ctx, con, !!!setNames(values, sql_names))
   },
 
   data_date = function(ctx, con) {
     #' - coercible using [as.Date()] for dates,
     as_date_equals_to <- function(x) {
-      lapply(x, function(xx) {
+      map(x, function(xx) {
         function(value) as.Date(value) == xx
       })
     }
@@ -70,7 +70,7 @@ spec_result_roundtrip <- list(
     sql_names <- ctx$tweaks$date_cast(char_values)
 
     #' with NA for SQL `NULL` values
-    test_select_with_null(.ctx = ctx, con, .dots = setNames(values, sql_names))
+    test_select_with_null(.ctx = ctx, con, !!!setNames(values, sql_names))
   },
 
   data_date_current = function(ctx, con) {
@@ -84,7 +84,7 @@ spec_result_roundtrip <- list(
   data_time = function(ctx, con) {
     #' - coercible using [hms::as_hms()] for times,
     as_hms_equals_to <- function(x) {
-      lapply(x, function(xx) {
+      map(x, function(xx) {
         function(value) hms::as_hms(value) == xx
       })
     }
@@ -94,7 +94,7 @@ spec_result_roundtrip <- list(
     sql_names <- ctx$tweaks$time_cast(char_values)
 
     #' with NA for SQL `NULL` values
-    test_select_with_null(.ctx = ctx, con, .dots = setNames(time_values, sql_names))
+    test_select_with_null(.ctx = ctx, con, !!!setNames(time_values, sql_names))
   },
 
   data_time_current = function(ctx, con) {
@@ -117,7 +117,7 @@ spec_result_roundtrip <- list(
     sql_names <- ctx$tweaks$timestamp_cast(char_values)
 
     #' with NA for SQL `NULL` values
-    test_select_with_null(.ctx = ctx, con, .dots = setNames(time_values, sql_names))
+    test_select_with_null(.ctx = ctx, con, !!!setNames(time_values, sql_names))
   },
 
   data_timestamp_current = function(ctx, con) {
@@ -145,10 +145,10 @@ spec_result_roundtrip <- list(
     }
 
     char_values <- paste0("2015-01-", sprintf("%.2d", 1:12))
-    values <- lapply(char_values, as_numeric_date)
+    values <- map(char_values, as_numeric_date)
     sql_names <- ctx$tweaks$date_cast(char_values)
 
-    test_select_with_null(.ctx = ctx, con, .dots = setNames(values, sql_names))
+    test_select_with_null(.ctx = ctx, con, !!!setNames(values, sql_names))
   },
 
   data_date_current_typed = function(ctx, con) {
@@ -173,7 +173,7 @@ spec_result_roundtrip <- list(
     timestamp_values <- rep(list(is_timestamp), 2L)
     sql_names <- ctx$tweaks$timestamp_cast(char_values)
 
-    test_select_with_null(.ctx = ctx, con, .dots = setNames(timestamp_values, sql_names))
+    test_select_with_null(.ctx = ctx, con, !!!setNames(timestamp_values, sql_names))
   },
 
   data_timestamp_current_typed = function(ctx, con) {
@@ -199,7 +199,7 @@ spec_result_roundtrip <- list(
   #'   to the true value
   data_64_bit_numeric = function(ctx, con) {
     as_numeric_identical_to <- function(x) {
-      lapply(x, function(xx) {
+      map(x, function(xx) {
         function(value) as.numeric(value) == xx
       })
     }
@@ -207,13 +207,13 @@ spec_result_roundtrip <- list(
     char_values <- c("10000000000", "-10000000000")
     test_values <- as_numeric_identical_to(as.numeric(char_values))
 
-    test_select_with_null(.ctx = ctx, con, .dots = setNames(test_values, char_values))
+    test_select_with_null(.ctx = ctx, con, !!!setNames(test_values, char_values))
   },
 
   #' - Loss of precision when converting to numeric gives a warning
   data_64_bit_numeric_warning = function(ctx, con) {
     as_numeric_equals_to <- function(x) {
-      lapply(x, function(xx) {
+      map(x, function(xx) {
         function(value) isTRUE(all.equal(as.numeric(value), xx))
       })
     }
@@ -224,17 +224,17 @@ spec_result_roundtrip <- list(
 
     suppressWarnings(
       expect_warning(
-        test_select(.ctx = ctx, con, .dots = setNames(test_values, char_values), .add_null = "none")
+        test_select(.ctx = ctx, con, !!!setNames(test_values, char_values), .add_null = "none")
       )
     )
     suppressWarnings(
       expect_warning(
-        test_select(.ctx = ctx, con, .dots = setNames(test_values, char_values), .add_null = "above")
+        test_select(.ctx = ctx, con, !!!setNames(test_values, char_values), .add_null = "above")
       )
     )
     suppressWarnings(
       expect_warning(
-        test_select(.ctx = ctx, con, .dots = setNames(test_values, char_values), .add_null = "below")
+        test_select(.ctx = ctx, con, !!!setNames(test_values, char_values), .add_null = "below")
       )
     )
   },
@@ -243,7 +243,7 @@ spec_result_roundtrip <- list(
   #'   of the data
   data_64_bit_lossless = function(ctx, con) {
     as_character_equals_to <- function(x) {
-      lapply(x, function(xx) {
+      map(x, function(xx) {
         function(value) as.character(value) == xx
       })
     }
@@ -251,7 +251,7 @@ spec_result_roundtrip <- list(
     char_values <- c("1234567890123456789", "-1234567890123456789")
     test_values <- as_character_equals_to(char_values)
 
-    test_select_with_null(.ctx = ctx, con, .dots = setNames(test_values, char_values))
+    test_select_with_null(.ctx = ctx, con, !!!setNames(test_values, char_values))
   },
   #
   NULL
@@ -264,13 +264,18 @@ test_select_with_null <- function(...) {
   test_select(..., .add_null = "below")
 }
 
-test_select <- function(con, ..., .dots = NULL, .add_null = "none",
-                        .ctx, .envir = parent.frame()) {
-  values <- c(list(...), .dots)
+test_select <- function(
+  con,
+  ...,
+  .add_null = "none",
+  .ctx,
+  .envir = parent.frame()) {
 
-  value_is_formula <- vapply(values, is.call, logical(1L))
-  names(values)[value_is_formula] <- lapply(values[value_is_formula], "[[", 2L)
-  values[value_is_formula] <- lapply(
+  values <- list2(...)
+
+  value_is_formula <- map_lgl(values, is.call)
+  names(values)[value_is_formula] <- map(values[value_is_formula], "[[", 2L)
+  values[value_is_formula] <- map(
     values[value_is_formula],
     function(x) {
       eval(x[[3]], envir = .envir)
@@ -278,7 +283,7 @@ test_select <- function(con, ..., .dots = NULL, .add_null = "none",
   )
 
   if (is.null(names(values))) {
-    sql_values <- lapply(values, as.character)
+    sql_values <- map(values, as.character)
   } else {
     sql_values <- names(values)
   }
@@ -350,7 +355,7 @@ equals_minus_100 <- function(x) {
 }
 
 all_have_utf8_or_ascii_encoding <- function(x) {
-  all(vapply(x, has_utf8_or_ascii_encoding, logical(1L)))
+  all(map_lgl(x, has_utf8_or_ascii_encoding))
 }
 
 has_utf8_or_ascii_encoding <- function(x) {
@@ -383,7 +388,7 @@ coercible_to_time <- function(x) {
 }
 
 as_timestamp_equals_to <- function(x) {
-  lapply(x, function(xx) {
+  map(x, function(xx) {
     function(value) as.POSIXct(value) == xx
   })
 }
