@@ -54,9 +54,9 @@ spec_sql_write_table <- list(
   write_table_error = function(ctx, con, table_name) {
     #' An error is also raised
     test_in <- data.frame(a = 1L)
-    #' if `name` cannot be processed with [dbQuoteIdentifier()]
+    #' if `name` cannot be processed with [dbQuoteIdentifier()] or
     expect_error(dbWriteTable(con, NA, test_in))
-    #' or if this results in a non-scalar.
+    #' if this results in a non-scalar.
     expect_error(dbWriteTable(con, c(table_name, table_name), test_in))
 
     #' Invalid values for the additional arguments `row.names`,
@@ -237,7 +237,7 @@ spec_sql_write_table <- list(
   },
 
   #'
-  temporary_table = function(ctx, con, table_name = "dbit08") {
+  temporary_table_1 = function(ctx, con, table_name = "dbit08") {
     #' If the `temporary` argument is `TRUE`, the table is not available in a
     #' second connection and is gone after reconnecting.
     #' Not all backends support this argument.
@@ -254,19 +254,23 @@ spec_sql_write_table <- list(
     expect_error(dbReadTable(con2, table_name))
   },
   # second stage
-  temporary_table = function(ctx, con) {
+  temporary_table_2 = function(ctx, con) {
     if (!isTRUE(ctx$tweaks$temporary_tables)) {
       skip("tweak: temporary_tables")
     }
 
+    # table_name not in formals on purpose: this means that this table won't be
+    # removed at the end of the test
     table_name <- "dbit08"
     expect_error(dbReadTable(con, table_name))
   },
 
-  table_visible_in_other_connection = function(ctx, local_con) {
+  table_visible_in_other_connection_1 = function(ctx, local_con) {
     #' A regular, non-temporary table is visible in a second connection,
     penguins30 <- get_penguins(ctx)
 
+    # table_name not in formals on purpose: this means that this table won't be
+    # removed at the end of the test
     table_name <- "dbit09"
 
     dbWriteTable(local_con, table_name, penguins30)
@@ -277,16 +281,18 @@ spec_sql_write_table <- list(
     expect_equal_df(dbReadTable(con2, table_name), penguins30)
   },
   # second stage
-  table_visible_in_other_connection = function(ctx, con) {
+  table_visible_in_other_connection_2 = function(ctx, con) {
     #' in a pre-existing connection,
     penguins30 <- get_penguins(ctx)
 
+    # table_name not in formals on purpose: this means that this table won't be
+    # removed at the end of the test
     table_name <- "dbit09"
 
     expect_equal_df(check_df(dbReadTable(con, table_name)), penguins30)
   },
   # third stage
-  table_visible_in_other_connection = function(ctx, local_con, table_name = "dbit09") {
+  table_visible_in_other_connection_3 = function(ctx, local_con, table_name = "dbit09") {
     #' and after reconnecting to the database.
     penguins30 <- get_penguins(ctx)
 
@@ -617,7 +623,7 @@ spec_sql_write_table <- list(
     test_table_roundtrip(
       con, tbl_in,
       transform = function(out) {
-        dates <- vapply(out, inherits, "POSIXt", FUN.VALUE = logical(1L))
+        dates <- map_lgl(out, inherits, "POSIXt")
         tz <- toupper(names(out))
         tz[tz == "LOCAL"] <- ""
         out[dates] <- Map(lubridate::with_tz, out[dates], tz[dates])
@@ -657,7 +663,7 @@ spec_sql_write_table <- list(
     test_table_roundtrip(
       con, tbl_in,
       transform = function(out) {
-        dates <- vapply(out, inherits, "POSIXt", FUN.VALUE = logical(1L))
+        dates <- map_lgl(out, inherits, "POSIXt")
         tz <- toupper(names(out))
         tz[tz == "LOCAL"] <- ""
         out[dates] <- Map(lubridate::with_tz, out[dates], tz[dates])
@@ -670,16 +676,16 @@ spec_sql_write_table <- list(
   roundtrip_mixed = function(ctx, con) {
     #' Mixing column types in the same table is supported.
     data <- list("a", 1L, 1.5)
-    data <- lapply(data, c, NA)
+    data <- map(data, c, NA)
     expanded <- expand.grid(a = data, b = data, c = data)
-    tbl_in_list <- lapply(
+    tbl_in_list <- map(
       seq_len(nrow(expanded)),
       function(i) {
-        as.data.frame(lapply(expanded[i, ], unlist, recursive = FALSE))
+        as.data.frame(map(expanded[i, ], unlist, recursive = FALSE))
       }
     )
 
-    lapply(tbl_in_list, test_table_roundtrip, con = con)
+    map(tbl_in_list, test_table_roundtrip, con = con)
   },
 
   #'
@@ -825,14 +831,14 @@ test_table_roundtrip <- function(...) {
 }
 
 test_table_roundtrip_one <- function(
-    con,
-    tbl_in,
-    tbl_expected = tbl_in,
-    transform = identity,
-    name = NULL,
-    field.types = NULL,
-    use_append = FALSE,
-    .add_na = "none") {
+  con,
+  tbl_in,
+  tbl_expected = tbl_in,
+  transform = identity,
+  name = NULL,
+  field.types = NULL,
+  use_append = FALSE,
+  .add_na = "none") {
   force(tbl_expected)
   if (.add_na == "above") {
     tbl_in <- add_na_above(tbl_in)
