@@ -13,7 +13,10 @@
 #'
 #' @param skip `[character()]`\cr A vector of regular expressions to match
 #'   against test names; skip test if matching any.
-#'   The regular expressions are matched against the entire test name.
+#'   The regular expressions are matched against the entire test name
+#'   minus a possible suffix `_N` where `N` is a number.
+#'   For example, `skip = "exists_table"` will skip both
+#'   `"exists_table_1"` and `"exists_table_2"`.
 #' @param run_only `[character()]`\cr A vector of regular expressions to match
 #'   against test names; run only these tests.
 #'   The regular expressions are matched against the entire test name.
@@ -30,6 +33,7 @@ test_all <- function(skip = NULL, run_only = NULL, ctx = get_default_context())
   if (run_all || Sys.getenv("DBITEST_ONLY_SQL") != "") test_sql(skip = skip, run_only = run_only, ctx = ctx)
   if (run_all || Sys.getenv("DBITEST_ONLY_META") != "") test_meta(skip = skip, run_only = run_only, ctx = ctx)
   if (run_all || Sys.getenv("DBITEST_ONLY_TRANSACTION") != "") test_transaction(skip = skip, run_only = run_only, ctx = ctx)
+  if (run_all || Sys.getenv("DBITEST_ONLY_ARROW") != "") test_arrow(skip = skip, run_only = run_only, ctx = ctx)
   if (run_all || Sys.getenv("DBITEST_ONLY_COMPLIANCE") != "") test_compliance(skip = skip, run_only = run_only, ctx = ctx)
   # stress tests are not tested by default (#92)
   invisible()
@@ -41,21 +45,8 @@ test_all <- function(skip = NULL, run_only = NULL, ctx = get_default_context())
 #'   A character vector of regular expressions
 #'   describing the tests to run.
 #'   The regular expressions are matched against the entire test name.
-#' @param dblog `[logical(1)]`\cr
-#'   Set to `FALSE` to disable dblog integration.
 #' @export
-test_some <- function(test, ctx = get_default_context(), dblog = TRUE) {
-  if (dblog) {
-    logger <- dblog::make_collect_logger(display = TRUE)
-
-    ctx$cnr <- dblog::dblog_cnr(ctx$cnr, logger)
-    ctx$drv <- ctx$cnr@.drv
-  }
-
+test_some <- function(test, ctx = get_default_context()) {
   test_all(run_only = test, skip = character(), ctx = ctx)
-
-  if (dblog && is_interactive()) {
-    clipr::write_clip(logger$retrieve())
-    message("DBI calls written to clipboard.")
-  }
+  invisible()
 }
