@@ -8,11 +8,11 @@ NULL
 #' Test full compliance to DBI
 #'
 #' @inheritParams test_all
-#' @include test-transaction.R
+#' @include test-arrow.R
 #' @family tests
 #' @export
-test_compliance <- function(skip = NULL, ctx = get_default_context()) {
+test_compliance <- function(skip = NULL, run_only = NULL, ctx = get_default_context()) {
   test_suite <- "Full compliance"
 
-  run_tests(ctx, spec_compliance, skip, test_suite)
+  run_tests(ctx, spec_compliance, skip, run_only, test_suite)
 }
