@@ -68,11 +68,6 @@ random_table_name <- function(n = 10) {
   paste0("dbit", paste(sample(letters, n, replace = TRUE), collapse = ""))
 }
 
-compact <- function(x) {
-  x[!vapply(x, is.null, logical(1L))]
-}
-
-
 try_silent <- function(code) {
   tryCatch(
     code,
@@ -83,7 +78,7 @@ try_silent <- function(code) {
 check_df <- function(df) {
   expect_s3_class(df, "data.frame")
   if (length(df) >= 1L) {
-    lengths <- vapply(df, length, integer(1L), USE.NAMES = FALSE)
+    lengths <- unname(lengths(df))
     expect_equal(diff(lengths), rep(0L, length(lengths) - 1L))
     expect_equal(nrow(df), lengths[[1]])
   }
@@ -95,6 +90,16 @@ check_df <- function(df) {
   df
 }
 
-check_arrow <- function(stream) {
-  check_df(as.data.frame(stream))
+check_arrow <- function(stream, transform = identity) {
+  to <- function(schema, ptype) transform(ptype)
+  if (inherits(stream, "nanoarrow_array_stream")) {
+    on.exit(stream$release())
+    df <- nanoarrow::convert_array_stream(stream, to)
+  } else if (inherits(stream, "nanoarrow_array")) {
+    df <- nanoarrow::convert_array(stream, to)
+  } else {
+    stop("Unexpected conversion of type ", class(stream), ".", call. = FALSE)
+  }
+
+  check_df(df)
 }
