@@ -1,5 +1,5 @@
 .onLoad <- function(libname, pkgname) {
-  if (rlang::is_installed("debugme")) {
+  if (is_installed("debugme")) {
     # Necessary to re-parse environment variable
     get(".onLoad", asNamespace("debugme"))(libname, pkgname)
 
